diff --git a/src/var/FeatureModelConfigurator/adapter.config b/src/var/FeatureModelConfigurator/adapter.config
index bc1d245234e1b376a33f27f3fd0c1c78d6403b16..fd4b43137f979effefd682a5d68960be63f2b517 100644
--- a/src/var/FeatureModelConfigurator/adapter.config
+++ b/src/var/FeatureModelConfigurator/adapter.config
@@ -8,13 +8,19 @@
 		<!-- Path to all available sensor configuration files. -->
 		<!-- Files with other endings are allowed and will be ignored, unless this path is also used by ModelSetup (see ModelSetup) -->
 		<sensorconfig type="directory" path="./resources/input/sensorconfig/" />
-		<!-- Path to all available .gazebo.xacro/ .urdf.xacro files. -->
+		<!-- Path to all available .gazebo.xacro files. -->
 		<!-- Files with other endings are allowed and will be ignored. -->
-		<bot_description type="directory" path="./../../sim/turtlebot3/turtlebot3/turtlebot3_description/urdf_raw_for_testing/" />
+		<gazebo_xacro type="directory" path="./../../sim/turtlebot3/turtlebot3/turtlebot3_description/urdf_raw_for_testing/" />
+		<!-- Path to all available .urdf.xacro files. -->
+		<!-- Files with other endings are allowed and will be ignored. -->
+		<urdf_xacro type="directory" path="./../../sim/turtlebot3/turtlebot3/turtlebot3_description/urdf_raw_for_testing/" />
 	</input>
 	<output>
-		<!-- Path to and name of the generated .gazebo.xacro/ .urdf.xacro/ file stating the selected bots name. -->
-		<bot_description type="file" gazebo_xacro="bot.gazebo.xacro" urdf_xacro="bot.urdf.xacro" botname="botname.txt" path="./../../../build/sim/" />
-		<botname /><!-- TODO -->
+		<!-- Path to and name of the generated .gazebo.xacro file. -->
+		<gazebo_xacro type="file" name="bot.gazebo.xacro" path="./../../../build/sim/" />
+		<!-- Path to and name of the generated .urdf.xacro file. -->
+		<urdf_xacro type="file" name="bot.urdf.xacro" path="./../../../build/sim/" />
+		<!-- Path to and name of the file stating the selected bots name. -->
+		<botname type="file" name="botname.txt" path="./../../../build/sim/" />
 	</output>
 </adapter>
diff --git a/src/var/FeatureModelConfigurator/features/ConfiguratorMain/Adapter.java b/src/var/FeatureModelConfigurator/features/ConfiguratorMain/Adapter.java
index 106cffe828935860e0f7b731675df2b0ba08b1bc..c20ebb4f8f23524fcfa818e8dd08c3ef370df9e0 100644
--- a/src/var/FeatureModelConfigurator/features/ConfiguratorMain/Adapter.java
+++ b/src/var/FeatureModelConfigurator/features/ConfiguratorMain/Adapter.java
@@ -46,14 +46,18 @@ public class Adapter extends XMLHelper {
 			
 			String in_fmPath = getConfigVal(adapterConfig, "input/featuremodel", "path");
 			String in_scPath = getConfigVal(adapterConfig, "input/sensorconfig", "path");
-			String in_descPath = getConfigVal(adapterConfig, "input/bot_description", "path");
-			String out_descPath = getConfigVal(adapterConfig, "output/bot_description", "path");
+			String in_gxPath = getConfigVal(adapterConfig, "input/gazebo_xacro", "path");
+			String in_uxPath = getConfigVal(adapterConfig, "input/urdf_xacro", "path");
+			String out_gxPath = getConfigVal(adapterConfig, "output/gazebo_xacro", "path");
+			String out_uxPath = getConfigVal(adapterConfig, "output/urdf_xacro", "path");
+			String out_bnPath = getConfigVal(adapterConfig, "output/botname", "path");
+
 			String in_fmName = getConfigVal(adapterConfig, "input/featuremodel", "name");
 			String in_gxName = "";
 			String in_uxName = "";
-			String out_gxName = getConfigVal(adapterConfig, "output/bot_description", "gazebo_xacro");
-			String out_uxName = getConfigVal(adapterConfig, "output/bot_description", "urdf_xacro");
-			String out_bnName = getConfigVal(adapterConfig, "output/bot_description", "botname");
+			String out_gxName = getConfigVal(adapterConfig, "output/gazebo_xacro", "name");
+			String out_uxName = getConfigVal(adapterConfig, "output/urdf_xacro", "name");
+			String out_bnName = getConfigVal(adapterConfig, "output/botname", "name");
 			
 			Document featureModel = readXml(in_fmPath+in_fmName);
 			List<Document> sensorConfigList = new ArrayList<Document>();
@@ -62,6 +66,7 @@ public class Adapter extends XMLHelper {
 			
 			//Get the selected mode (either NO_CHANGE or Custom) as String.
 			String mode = "";
+			
 			List<Attribute> modeList = xQueryAttributes(featureModel, "//mode/@param");
 			if(modeList.size()==1) {
 				mode = modeList.get(0).getValue();
@@ -99,8 +104,9 @@ public class Adapter extends XMLHelper {
 					System.exit(-1);
 			}
 			
-			//Get the selected .gazebo.xacro file as Document.
+			//Get the name of the selected bot as String.
 			String botName = "";
+			
 			List<Attribute> botList = xQueryAttributes(featureModel, "//templates/@name");
 			if(botList.size()==1) {
 				botName = botList.get(0).getValue();
@@ -110,9 +116,10 @@ public class Adapter extends XMLHelper {
 				System.exit(-1);
 			}
 
+			//Get the selected .gazebo.xacro file as Document.
 			in_gxName = botName+GX_ENDING;
 			
-			List<String> gxList = getFileNames(in_descPath);
+			List<String> gxList = getFileNames(in_gxPath);
 			boolean inDirectory = false;
 			for(String fileName : gxList) {
 				if(fileName.equals(in_gxName)) inDirectory = true;
@@ -122,12 +129,12 @@ public class Adapter extends XMLHelper {
 				System.exit(-1);
 			}
 			
-			gazeboModel = readXml(in_descPath+in_gxName);
+			gazeboModel = readXml(in_gxPath+in_gxName);
 			
 			//Get the corresponding .urdf.xacro file as Document.
 			in_uxName = botName+UX_ENDING;
 			
-			List<String> urdfList = getFileNames(in_descPath);
+			List<String> urdfList = getFileNames(in_uxPath);
 			inDirectory = false;
 			for(String fileName : urdfList) {
 				if(fileName.equals(in_uxName)) inDirectory = true;
@@ -137,7 +144,7 @@ public class Adapter extends XMLHelper {
 				System.exit(-1);
 			}
 			
-			urdfModel = readXml(in_descPath+in_uxName);
+			urdfModel = readXml(in_uxPath+in_uxName);
 			//###############################################
 			
 			
@@ -192,18 +199,18 @@ public class Adapter extends XMLHelper {
 			//###############################################
 			
 			
-			//######### Operate on .urdf.xacro ############
-			final Namespace ns = urdfModel.getRootElement().getNamespace("xacro");
+			//######### Operate on .urdf.xacro ##############
+			final Namespace NS = urdfModel.getRootElement().getNamespace("xacro");
 			
 			//Set <xacro:include> tags
-			List<Element> includeList = xQueryElements(urdfModel, "//xacro:include", ns);
+			List<Element> includeList = xQueryElements(urdfModel, "//xacro:include", NS);
 			if(includeList.size()!=2) {
 				System.err.println("Invalid input in \'"+in_uxName+"\': Expected exactly 2 xacro:include tags.");
 				System.exit(-1);
 			}
-			String destDirectoryName = (new File(out_descPath)).getName();
-			//includeList.get(0).setAttribute("filename", "$(find "+destDirectoryName+")/common_properties.xacro");//TODO
-			includeList.get(1).setAttribute("filename", "$(find "+destDirectoryName+")/"+out_gxName);
+			String gxDestDirectoryName = (new File(out_gxPath)).getName();
+			//includeList.get(0).setAttribute("filename", "$(find "+CommonPropDestDirectoryName+")/common_properties.xacro");//TODO
+			includeList.get(1).setAttribute("filename", "$(find "+gxDestDirectoryName+")/"+out_gxName);
 			
 			switch(mode) {
 				case "NO_CHANGE":
@@ -222,11 +229,11 @@ public class Adapter extends XMLHelper {
 			
 			
 			//######### Output result #######################
-			saveAsXml(gazeboModel, out_descPath+out_gxName);
+			saveAsXml(gazeboModel, out_gxPath+out_gxName);
 			
-			saveAsXml(urdfModel, out_descPath+out_uxName);
+			saveAsXml(urdfModel, out_uxPath+out_uxName);
 			
-			BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(out_descPath+out_bnName));
+			BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(out_bnPath+out_bnName));
 			bufferedWriter.write(botName);
 			bufferedWriter.close();
 			//###############################################
diff --git a/src/var/FeatureModelConfigurator/src/Adapter.java b/src/var/FeatureModelConfigurator/src/Adapter.java
index 106cffe828935860e0f7b731675df2b0ba08b1bc..c20ebb4f8f23524fcfa818e8dd08c3ef370df9e0 100644
--- a/src/var/FeatureModelConfigurator/src/Adapter.java
+++ b/src/var/FeatureModelConfigurator/src/Adapter.java
@@ -46,14 +46,18 @@ public class Adapter extends XMLHelper {
 			
 			String in_fmPath = getConfigVal(adapterConfig, "input/featuremodel", "path");
 			String in_scPath = getConfigVal(adapterConfig, "input/sensorconfig", "path");
-			String in_descPath = getConfigVal(adapterConfig, "input/bot_description", "path");
-			String out_descPath = getConfigVal(adapterConfig, "output/bot_description", "path");
+			String in_gxPath = getConfigVal(adapterConfig, "input/gazebo_xacro", "path");
+			String in_uxPath = getConfigVal(adapterConfig, "input/urdf_xacro", "path");
+			String out_gxPath = getConfigVal(adapterConfig, "output/gazebo_xacro", "path");
+			String out_uxPath = getConfigVal(adapterConfig, "output/urdf_xacro", "path");
+			String out_bnPath = getConfigVal(adapterConfig, "output/botname", "path");
+
 			String in_fmName = getConfigVal(adapterConfig, "input/featuremodel", "name");
 			String in_gxName = "";
 			String in_uxName = "";
-			String out_gxName = getConfigVal(adapterConfig, "output/bot_description", "gazebo_xacro");
-			String out_uxName = getConfigVal(adapterConfig, "output/bot_description", "urdf_xacro");
-			String out_bnName = getConfigVal(adapterConfig, "output/bot_description", "botname");
+			String out_gxName = getConfigVal(adapterConfig, "output/gazebo_xacro", "name");
+			String out_uxName = getConfigVal(adapterConfig, "output/urdf_xacro", "name");
+			String out_bnName = getConfigVal(adapterConfig, "output/botname", "name");
 			
 			Document featureModel = readXml(in_fmPath+in_fmName);
 			List<Document> sensorConfigList = new ArrayList<Document>();
@@ -62,6 +66,7 @@ public class Adapter extends XMLHelper {
 			
 			//Get the selected mode (either NO_CHANGE or Custom) as String.
 			String mode = "";
+			
 			List<Attribute> modeList = xQueryAttributes(featureModel, "//mode/@param");
 			if(modeList.size()==1) {
 				mode = modeList.get(0).getValue();
@@ -99,8 +104,9 @@ public class Adapter extends XMLHelper {
 					System.exit(-1);
 			}
 			
-			//Get the selected .gazebo.xacro file as Document.
+			//Get the name of the selected bot as String.
 			String botName = "";
+			
 			List<Attribute> botList = xQueryAttributes(featureModel, "//templates/@name");
 			if(botList.size()==1) {
 				botName = botList.get(0).getValue();
@@ -110,9 +116,10 @@ public class Adapter extends XMLHelper {
 				System.exit(-1);
 			}
 
+			//Get the selected .gazebo.xacro file as Document.
 			in_gxName = botName+GX_ENDING;
 			
-			List<String> gxList = getFileNames(in_descPath);
+			List<String> gxList = getFileNames(in_gxPath);
 			boolean inDirectory = false;
 			for(String fileName : gxList) {
 				if(fileName.equals(in_gxName)) inDirectory = true;
@@ -122,12 +129,12 @@ public class Adapter extends XMLHelper {
 				System.exit(-1);
 			}
 			
-			gazeboModel = readXml(in_descPath+in_gxName);
+			gazeboModel = readXml(in_gxPath+in_gxName);
 			
 			//Get the corresponding .urdf.xacro file as Document.
 			in_uxName = botName+UX_ENDING;
 			
-			List<String> urdfList = getFileNames(in_descPath);
+			List<String> urdfList = getFileNames(in_uxPath);
 			inDirectory = false;
 			for(String fileName : urdfList) {
 				if(fileName.equals(in_uxName)) inDirectory = true;
@@ -137,7 +144,7 @@ public class Adapter extends XMLHelper {
 				System.exit(-1);
 			}
 			
-			urdfModel = readXml(in_descPath+in_uxName);
+			urdfModel = readXml(in_uxPath+in_uxName);
 			//###############################################
 			
 			
@@ -192,18 +199,18 @@ public class Adapter extends XMLHelper {
 			//###############################################
 			
 			
-			//######### Operate on .urdf.xacro ############
-			final Namespace ns = urdfModel.getRootElement().getNamespace("xacro");
+			//######### Operate on .urdf.xacro ##############
+			final Namespace NS = urdfModel.getRootElement().getNamespace("xacro");
 			
 			//Set <xacro:include> tags
-			List<Element> includeList = xQueryElements(urdfModel, "//xacro:include", ns);
+			List<Element> includeList = xQueryElements(urdfModel, "//xacro:include", NS);
 			if(includeList.size()!=2) {
 				System.err.println("Invalid input in \'"+in_uxName+"\': Expected exactly 2 xacro:include tags.");
 				System.exit(-1);
 			}
-			String destDirectoryName = (new File(out_descPath)).getName();
-			//includeList.get(0).setAttribute("filename", "$(find "+destDirectoryName+")/common_properties.xacro");//TODO
-			includeList.get(1).setAttribute("filename", "$(find "+destDirectoryName+")/"+out_gxName);
+			String gxDestDirectoryName = (new File(out_gxPath)).getName();
+			//includeList.get(0).setAttribute("filename", "$(find "+CommonPropDestDirectoryName+")/common_properties.xacro");//TODO
+			includeList.get(1).setAttribute("filename", "$(find "+gxDestDirectoryName+")/"+out_gxName);
 			
 			switch(mode) {
 				case "NO_CHANGE":
@@ -222,11 +229,11 @@ public class Adapter extends XMLHelper {
 			
 			
 			//######### Output result #######################
-			saveAsXml(gazeboModel, out_descPath+out_gxName);
+			saveAsXml(gazeboModel, out_gxPath+out_gxName);
 			
-			saveAsXml(urdfModel, out_descPath+out_uxName);
+			saveAsXml(urdfModel, out_uxPath+out_uxName);
 			
-			BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(out_descPath+out_bnName));
+			BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(out_bnPath+out_bnName));
 			bufferedWriter.write(botName);
 			bufferedWriter.close();
 			//###############################################
diff --git a/src/var/FeatureModelImplGenerator/modelsetup.config b/src/var/FeatureModelImplGenerator/modelsetup.config
index b6d7141ddd93a6ba53898e8d9098d58cc9ce6194..cbff7cb8b4c6c457c869618eac9af2dbec97bf8e 100644
--- a/src/var/FeatureModelImplGenerator/modelsetup.config
+++ b/src/var/FeatureModelImplGenerator/modelsetup.config
@@ -10,8 +10,7 @@
 		<sensorconfig type="directory" path="./../FeatureModelConfigurator/resources/input/sensorconfig/" />
 		<!-- Path to all available .gazebo.xacro files. -->
 		<!-- Files with other endings are allowed and will be ignored. -->
-		<bot_description type="directory" path="./../../sim/turtlebot3/turtlebot3/turtlebot3_description/urdf/" />
-			<!-- <gazebomodel type="directory" path="./../FeatureModelConfigurator/resources/input/bot_description/" /> -->
+		<gazebo_xacro type="directory" path="./../../sim/turtlebot3/turtlebot3/turtlebot3_description/urdf/" />
 	</input>
 	<output>
 		<!-- Path to and name of the generated Feature IDE model file. -->
diff --git a/src/var/FeatureModelImplGenerator/src/Adapter.java b/src/var/FeatureModelImplGenerator/src/Adapter.java
index 106cffe828935860e0f7b731675df2b0ba08b1bc..c20ebb4f8f23524fcfa818e8dd08c3ef370df9e0 100644
--- a/src/var/FeatureModelImplGenerator/src/Adapter.java
+++ b/src/var/FeatureModelImplGenerator/src/Adapter.java
@@ -46,14 +46,18 @@ public class Adapter extends XMLHelper {
 			
 			String in_fmPath = getConfigVal(adapterConfig, "input/featuremodel", "path");
 			String in_scPath = getConfigVal(adapterConfig, "input/sensorconfig", "path");
-			String in_descPath = getConfigVal(adapterConfig, "input/bot_description", "path");
-			String out_descPath = getConfigVal(adapterConfig, "output/bot_description", "path");
+			String in_gxPath = getConfigVal(adapterConfig, "input/gazebo_xacro", "path");
+			String in_uxPath = getConfigVal(adapterConfig, "input/urdf_xacro", "path");
+			String out_gxPath = getConfigVal(adapterConfig, "output/gazebo_xacro", "path");
+			String out_uxPath = getConfigVal(adapterConfig, "output/urdf_xacro", "path");
+			String out_bnPath = getConfigVal(adapterConfig, "output/botname", "path");
+
 			String in_fmName = getConfigVal(adapterConfig, "input/featuremodel", "name");
 			String in_gxName = "";
 			String in_uxName = "";
-			String out_gxName = getConfigVal(adapterConfig, "output/bot_description", "gazebo_xacro");
-			String out_uxName = getConfigVal(adapterConfig, "output/bot_description", "urdf_xacro");
-			String out_bnName = getConfigVal(adapterConfig, "output/bot_description", "botname");
+			String out_gxName = getConfigVal(adapterConfig, "output/gazebo_xacro", "name");
+			String out_uxName = getConfigVal(adapterConfig, "output/urdf_xacro", "name");
+			String out_bnName = getConfigVal(adapterConfig, "output/botname", "name");
 			
 			Document featureModel = readXml(in_fmPath+in_fmName);
 			List<Document> sensorConfigList = new ArrayList<Document>();
@@ -62,6 +66,7 @@ public class Adapter extends XMLHelper {
 			
 			//Get the selected mode (either NO_CHANGE or Custom) as String.
 			String mode = "";
+			
 			List<Attribute> modeList = xQueryAttributes(featureModel, "//mode/@param");
 			if(modeList.size()==1) {
 				mode = modeList.get(0).getValue();
@@ -99,8 +104,9 @@ public class Adapter extends XMLHelper {
 					System.exit(-1);
 			}
 			
-			//Get the selected .gazebo.xacro file as Document.
+			//Get the name of the selected bot as String.
 			String botName = "";
+			
 			List<Attribute> botList = xQueryAttributes(featureModel, "//templates/@name");
 			if(botList.size()==1) {
 				botName = botList.get(0).getValue();
@@ -110,9 +116,10 @@ public class Adapter extends XMLHelper {
 				System.exit(-1);
 			}
 
+			//Get the selected .gazebo.xacro file as Document.
 			in_gxName = botName+GX_ENDING;
 			
-			List<String> gxList = getFileNames(in_descPath);
+			List<String> gxList = getFileNames(in_gxPath);
 			boolean inDirectory = false;
 			for(String fileName : gxList) {
 				if(fileName.equals(in_gxName)) inDirectory = true;
@@ -122,12 +129,12 @@ public class Adapter extends XMLHelper {
 				System.exit(-1);
 			}
 			
-			gazeboModel = readXml(in_descPath+in_gxName);
+			gazeboModel = readXml(in_gxPath+in_gxName);
 			
 			//Get the corresponding .urdf.xacro file as Document.
 			in_uxName = botName+UX_ENDING;
 			
-			List<String> urdfList = getFileNames(in_descPath);
+			List<String> urdfList = getFileNames(in_uxPath);
 			inDirectory = false;
 			for(String fileName : urdfList) {
 				if(fileName.equals(in_uxName)) inDirectory = true;
@@ -137,7 +144,7 @@ public class Adapter extends XMLHelper {
 				System.exit(-1);
 			}
 			
-			urdfModel = readXml(in_descPath+in_uxName);
+			urdfModel = readXml(in_uxPath+in_uxName);
 			//###############################################
 			
 			
@@ -192,18 +199,18 @@ public class Adapter extends XMLHelper {
 			//###############################################
 			
 			
-			//######### Operate on .urdf.xacro ############
-			final Namespace ns = urdfModel.getRootElement().getNamespace("xacro");
+			//######### Operate on .urdf.xacro ##############
+			final Namespace NS = urdfModel.getRootElement().getNamespace("xacro");
 			
 			//Set <xacro:include> tags
-			List<Element> includeList = xQueryElements(urdfModel, "//xacro:include", ns);
+			List<Element> includeList = xQueryElements(urdfModel, "//xacro:include", NS);
 			if(includeList.size()!=2) {
 				System.err.println("Invalid input in \'"+in_uxName+"\': Expected exactly 2 xacro:include tags.");
 				System.exit(-1);
 			}
-			String destDirectoryName = (new File(out_descPath)).getName();
-			//includeList.get(0).setAttribute("filename", "$(find "+destDirectoryName+")/common_properties.xacro");//TODO
-			includeList.get(1).setAttribute("filename", "$(find "+destDirectoryName+")/"+out_gxName);
+			String gxDestDirectoryName = (new File(out_gxPath)).getName();
+			//includeList.get(0).setAttribute("filename", "$(find "+CommonPropDestDirectoryName+")/common_properties.xacro");//TODO
+			includeList.get(1).setAttribute("filename", "$(find "+gxDestDirectoryName+")/"+out_gxName);
 			
 			switch(mode) {
 				case "NO_CHANGE":
@@ -222,11 +229,11 @@ public class Adapter extends XMLHelper {
 			
 			
 			//######### Output result #######################
-			saveAsXml(gazeboModel, out_descPath+out_gxName);
+			saveAsXml(gazeboModel, out_gxPath+out_gxName);
 			
-			saveAsXml(urdfModel, out_descPath+out_uxName);
+			saveAsXml(urdfModel, out_uxPath+out_uxName);
 			
-			BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(out_descPath+out_bnName));
+			BufferedWriter bufferedWriter = new BufferedWriter(new FileWriter(out_bnPath+out_bnName));
 			bufferedWriter.write(botName);
 			bufferedWriter.close();
 			//###############################################
diff --git a/src/var/FeatureModelImplGenerator/src/ModelSetup.java b/src/var/FeatureModelImplGenerator/src/ModelSetup.java
index 2ed76246123655904269993f170fbd6e3158cd0d..f6189b7318214b9e164f95db72ee4fe9e316d4bc 100644
--- a/src/var/FeatureModelImplGenerator/src/ModelSetup.java
+++ b/src/var/FeatureModelImplGenerator/src/ModelSetup.java
@@ -44,7 +44,7 @@ public class ModelSetup extends XMLHelper{
 			
 			String in_mPath = getConfigVal(ModelSetupConfig, "input/model", "path");
 			String in_scPath = getConfigVal(ModelSetupConfig, "input/sensorconfig", "path");
-			String in_descPath = getConfigVal(ModelSetupConfig, "input/bot_description", "path");
+			String in_gxPath = getConfigVal(ModelSetupConfig, "input/gazebo_xacro", "path");
 			String out_mPath = getConfigVal(ModelSetupConfig, "output/model", "path");
 			String in_mName = getConfigVal(ModelSetupConfig, "input/model", "name");
 			String out_mName = getConfigVal(ModelSetupConfig, "output/model", "name");
@@ -52,12 +52,18 @@ public class ModelSetup extends XMLHelper{
 			Document model = readXml(in_mPath+in_mName);
 			
 			//Get sensorconfig- and gazebomodel file names.
-			//All files in in_scPath will be treated as sensorconfigs, while in_descPath may
-			//contain other files that will be filtered out!
-			List<String> scList = getFileNames(in_scPath);
-			List<String> tmpList = getFileNames(in_descPath);
+			//Files in in_scPath and in_gxPath  may contain other files that will be filtered out!
+			List<String> scDirectoryFilesList = getFileNames(in_scPath);
+			List<String> scList = new ArrayList<String>();
+			for(String s : scDirectoryFilesList) {
+				if(s.endsWith(SC_ENDING)) {
+					scList.add(s);
+				}
+			}
+			
+			List<String> gxDirectoryFilesList = getFileNames(in_gxPath);
 			List<String> gxList = new ArrayList<String>();
-			for(String s : tmpList) {
+			for(String s : gxDirectoryFilesList) {
 				if(s.endsWith(GX_ENDING)) {
 					gxList.add(s);
 				}
@@ -67,21 +73,13 @@ public class ModelSetup extends XMLHelper{
 			//It is possible to have no sensors (so you can build a custom bot with no sensors), 
 			//but at least one bot template is required!
 			if(scList.isEmpty()) {
-				System.out.println("Warning: No sensorconfig files found in \'"+in_scPath+"\'.");
+				System.out.println("Warning: No sensorconfig \'"+SC_ENDING+"\' files found in \'"+in_scPath+"\'.");
 			}
 			if(gxList.isEmpty()) {
-				System.err.println("Error: No \'"+GX_ENDING+"\' files found in \'"+in_descPath+"\'.");
+				System.err.println("Error: No gazebo model \'"+GX_ENDING+"\' files found in \'"+in_gxPath+"\'.");
 				System.exit(-1);
 			}
 			
-			//Check for well formed file names.
-			for(String sc : scList) {
-				if(!sc.endsWith(SC_ENDING)) {
-					System.err.println("Error: sensorconfig file \'"+sc+"\' does not have an \'"+SC_ENDING+"\' ending.");
-					System.exit(-1);
-				}
-			}
-			
 			//Sort features alphabetically (ascending order; upper case first; then lower case).
 			Collections.sort(scList);
 			Collections.sort(gxList);